CupertinoSwitchTokenResolver class
Cupertino token resolver for Switch components.
Implements RSwitchTokenResolver with iOS styling.
Constructors
- CupertinoSwitchTokenResolver({Brightness? brightness})
-
const
Properties
- brightness → Brightness?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
{required BuildContext context, required RSwitchSpec spec, required Set< WidgetState> states, BoxConstraints? constraints, RenderOverrides? overrides}) → RSwitchResolvedTokens -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited